@@ -10,8 +10,8 @@ var MazeModel = widgets.DOMWidgetModel.extend({
 		_view_name: "MazeView",
 		_model_module: "ttgtcanvas",
 		_view_module: "ttgtcanvas",
-		_model_module_version: "0.2.6",
-		_view_module_version: "0.2.6",
+		_model_module_version: "0.2.7",
+		_view_module_version: "0.2.7",
 		current_call: "{}",
 		method_return: "{}",
 	}),
@@ -133,11 +133,15 @@ class Robot {
 	set_image(src, index) {
 		return new Promise((resolve, reject) => {
 			let that = this;
-			new Konva.Image.fromURL(this.src, function (darthNode) {
+
+			new Konva.Image.fromURL(src, function (darthNode) {
+				that.src = src;
 				that.set_node(darthNode);
 				darthNode.setAttrs({
 					x: 100,
 					y: 100,
+					width: 32,
+					height: 32,
 					name: `robot-${index}`,
 				});
 				that.layer.add(darthNode);
@@ -245,6 +249,7 @@ var MazeView = widgets.DOMWidgetView.extend({
 		this._elem.setAttribute("id", "container");
 		this.layer = new Konva.Layer();
 		this.line_layer = new Konva.Layer();
+		this.msg_layer = new Konva.Layer();
 		this.robots = [];
 		this.el.appendChild(this._elem);
 		this.method_changed();
@@ -252,8 +257,9 @@ var MazeView = widgets.DOMWidgetView.extend({
 	},
 
 	add_robot: function (robot_index, src, avenue, street, orientation, beepers) {
-		if (this.robots[robot_index]) {
-			return Promise.resolve("robot exists");
+		let robot = this.robots[robot_index];
+		if (robot) {
+			if (robot.node) robot.node.destroy();
 		}
 
 		this.robots[robot_index] = new Robot({
@@ -308,6 +314,7 @@ var MazeView = widgets.DOMWidgetView.extend({
 
 	init_robot: function (robot_index) {
 		let robot = this.robots[robot_index];
+		this.delete_msg();
 		if (robot) {
 			while (robot.angle !== 0) {
 				robot.rotate_left();
@@ -343,7 +350,134 @@ var MazeView = widgets.DOMWidgetView.extend({
 		robot.rotate_left();
 	},
 
+	success_msg: function (msg) {
+		this.delete_msg();
+
+		let msg_group = new Konva.Group({
+			opacity: 0,
+			name: "overlay-msg",
+		});
+		var rect2 = new Konva.Rect({
+			x: 60,
+			y: 125,
+			width: 400,
+			height: 200,
+			fill: "white",
+			shadowBlur: 10,
+			cornerRadius: 10,
+		});
+
+		var circle2 = new Konva.Circle({
+			radius: 40,
+			x: 260,
+			y: 130,
+			fill: "green",
+			stroke: "green",
+			strokeWidth: 5,
+		});
+
+		var check = new Konva.Text({
+			x: 240,
+			y: 110,
+			text: "✔",
+			align: "center",
+			fontSize: 50,
+			fontFamily: "Calibri",
+			fill: "white",
+		});
+
+		var msg = new Konva.Text({
+			x: 120,
+			y: 200,
+			text: "Congrats, \n Task Completed.",
+			align: "center",
+			fontSize: 40,
+			fontFamily: "Calibri",
+			fill: "green",
+		});
+
+		msg_group.add(rect2, circle2, msg, check);
+		this.msg_layer.add(msg_group);
+
+		var tween = new Konva.Tween({
+			node: msg_group,
+			opacity: 1,
+			easing: Konva.Easings["EaseOut"],
+			duration: 5,
+		});
+		tween.play();
+	},
+
+	delete_msg: function () {
+		let msg = this.msg_layer.find(`.overlay-msg`);
+		if (msg) {
+			msg.destroy();
+			msg.draw();
+		}
+	},
+	failed_msg: function (msg) {
+		this.delete_msg();
+
+		let msg_group = new Konva.Group({
+			opacity: 0,
+			name: "overlay-msg",
+		});
+
+		var rect2 = new Konva.Rect({
+			x: 60,
+			y: 125,
+			width: 400,
+			height: 200,
+			fill: "white",
+			shadowBlur: 10,
+			cornerRadius: 10,
+		});
+
+		var circle2 = new Konva.Circle({
+			radius: 40,
+			x: 260,
+			y: 130,
+			fill: "red",
+			stroke: "red",
+			align: "center",
+			strokeWidth: 5,
+		});
+
+		var check = new Konva.Text({
+			x: 247,
+			y: 102,
+			text: "x",
+			align: "center",
+			fontSize: 50,
+			fontFamily: "Calibri",
+			fill: "white",
+		});
+
+		var msg = new Konva.Text({
+			x: 120,
+			y: 200,
+			text: "Opps, Task Failed.",
+			align: "center",
+			fontSize: 40,
+			fontFamily: "Calibri",
+			fill: "red",
+		});
+
+		msg_group.add(rect2, circle2, msg, check);
+		this.msg_layer.add(msg_group);
+
+		var tween = new Konva.Tween({
+			node: msg_group,
+			opacity: 1,
+			easing: Konva.Easings["EaseOut"],
+			duration: 5,
+		});
+		tween.play();
+	},
+
 	draw_grid: function (width, height, av, st, ts, walls, beepers) {
+		this._width = width;
+		this._heigth = height;
 		this.stage = new Konva.Stage({
 			container: "container",
 			width: width,
@@ -353,6 +487,7 @@ var MazeView = widgets.DOMWidgetView.extend({
 		// add canvas element
 		this.stage.add(this.layer);
 		this.stage.add(this.line_layer);
+		this.stage.add(this.msg_layer);
 		//init
 		this.ts = ts;
 		let left = 2 * ts;
