@@ -345,6 +345,17 @@ class Maze(widgets.DOMWidget):
     def rotate_left(self, rindex):
         self.js_call('rotate_left', [rindex])
 
+    def beepers_count(self):
+        return len(self.beepers)
+    
+    def check(self):
+        ret = self.beepers_count() == 0
+        if ret == True:
+            self.js_call('success_msg', ["Congrats, Task Completed."])
+        else:
+            self.js_call('failed_msg', ["Oops, Task Failed."])
+        return ret
+
     def add_beeper(self, av, st):
         x, y = self.cr2xy(2 * av - 1, 2 * st - 1)
         """Add a single beeper."""
